Package: calmate
Version: 0.13.0
Depends: R (>= 3.2.1), R.utils (>= 2.11.0), aroma.core (>= 3.2.2)
Imports: utils, MASS, R.methodsS3 (>= 1.8.1), R.oo (>= 1.24.0),
        matrixStats (>= 0.61.0), R.filesets (>= 2.14.0)
Suggests: DNAcopy
Title: Improved Allele-Specific Copy Number of SNP Microarrays for
        Downstream Segmentation
Description: The CalMaTe method calibrates preprocessed allele-specific copy number estimates (ASCNs) from DNA microarrays by controlling for single-nucleotide polymorphism-specific allelic crosstalk. The resulting ASCNs are on average more accurate, which increases the power of segmentation methods for detecting changes between copy number states in tumor studies including copy neutral loss of heterozygosity. CalMaTe applies to any ASCNs regardless of preprocessing method and microarray technology, e.g. Affymetrix and Illumina.
Authors@R: c(
  person("Maria", "Ortiz", role=c("aut", "ctb")),
  person("Ander", "Aramburu", role=c("ctb")),
  person("Henrik", "Bengtsson", role=c("aut", "cre", "cph"),
                                 email="henrikb@braju.com"),
  person("Pierre", "Neuvial", role=c("aut", "ctb")),
  person("Angel", "Rubio", role=c("aut", "ctb")))
License: LGPL (>= 2.1)
URL: https://github.com/HenrikBengtsson/calmate/
BugReports: https://github.com/HenrikBengtsson/calmate/issues
LazyLoad: TRUE
biocViews: aCGH, CopyNumberVariants, SNP, Microarray, OneChannel,
        TwoChannel, Genetics
NeedsCompilation: no
Packaged: 2022-03-08 19:16:14 UTC; hb
Author: Maria Ortiz [aut, ctb],
  Ander Aramburu [ctb],
  Henrik Bengtsson [aut, cre, cph],
  Pierre Neuvial [aut, ctb],
  Angel Rubio [aut, ctb]
Maintainer: Henrik Bengtsson <henrikb@braju.com>
Repository: CRAN
Date/Publication: 2022-03-08 23:00:03 UTC
Built: R 4.6.0; ; 2026-04-26 11:58:24 UTC; unix
